@@ -99,6 +99,7 @@
 #include "messagedialog.h"
 #include "misc.h"
 #include "notebook.h"
+#include "numerableicon.h"
 #include "offscreenwindow.h"
 #include "orientable.h"
 #include "pagesetup.h"
@@ -277,6 +278,7 @@ GType gtk_menu_tool_button_get_type(void);
 GType gtk_message_dialog_get_type(void);
 GType gtk_misc_get_type(void);
 GType gtk_notebook_get_type(void);
+GType gtk_numerable_icon_get_type(void);
 GType gtk_offscreen_window_get_type(void);
 GType gtk_page_setup_get_type(void);
 #ifndef G_OS_WIN32
@@ -460,6 +462,7 @@ namespace Gtk {  class MenuToolButton_Class { public: static Glib::ObjectBase* w
 namespace Gtk {  class MessageDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Misc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Notebook_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class NumerableIcon_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class OffscreenWindow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class PageSetup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef G_OS_WIN32
@@ -643,6 +646,7 @@ void wrap_init()
   Glib::wrap_register(gtk_message_dialog_get_type(), &Gtk::MessageDialog_Class::wrap_new);
   Glib::wrap_register(gtk_misc_get_type(), &Gtk::Misc_Class::wrap_new);
   Glib::wrap_register(gtk_notebook_get_type(), &Gtk::Notebook_Class::wrap_new);
+  Glib::wrap_register(gtk_numerable_icon_get_type(), &Gtk::NumerableIcon_Class::wrap_new);
   Glib::wrap_register(gtk_offscreen_window_get_type(), &Gtk::OffscreenWindow_Class::wrap_new);
   Glib::wrap_register(gtk_page_setup_get_type(), &Gtk::PageSetup_Class::wrap_new);
 #ifndef G_OS_WIN32
@@ -814,6 +818,7 @@ void wrap_init()
   Gtk::MessageDialog::get_type();
   Gtk::Misc::get_type();
   Gtk::Notebook::get_type();
+  Gtk::NumerableIcon::get_type();
   Gtk::OffscreenWindow::get_type();
   Gtk::PageSetup::get_type();
 #ifndef G_OS_WIN32
